Enum core::str::pattern::SearchStep
[−]
[src]
pub enum SearchStep {
Match(usize, usize),
Reject(usize, usize),
Done,
}Result of calling Searcher::next() or ReverseSearcher::next_back().
Variants
Match | Expresses that a match of the pattern has been found at
| |
Reject | Expresses that Note that there might be more than one | |
Done | Expresses that every byte of the haystack has been visted, ending the iteration. |